@@ -4,26 +4,29 @@ import tornado.websocket
 
 
 class Broadcast(tornado.websocket.WebSocketHandler):
-    def initialize(self, sockets):
-        self.sockets = sockets
+    def initialize(self, websockets=None):
+        if websockets is None:
+            self.websockets = self.application.websockets
+        else:
+            self.websockets = websockets
 
     def open(self):
         self.stream.set_nodelay(True)
 
-        self.sockets.add(self)
+        self.websockets.add(self)
 
     def on_message(self, msg):
         if msg == 'ping':
             return
 
-        for ws in self.sockets:
+        for ws in self.websockets:
             if ws is self:
                 continue
             ws.write_message(msg)
 
     def on_close(self):
         try:
-            self.sockets.remove(self)
+            self.websockets.remove(self)
         except KeyError:
             pass
 
